package io

import (
	"encoding/json"
	"io"

	"git.sr.ht/~charles/rq/util"
	"github.com/alecthomas/chroma/v2/quick"
)

func init() {
	registerOutputHandler("json", func() OutputHandler { return &JSONOutputHandler{} })
}

// Declare conformance with OutputHandler interface.
var _ OutputHandler = &JSONOutputHandler{}

// JSONOutputHandler handles serializing JSON data.
type JSONOutputHandler struct {
	indent      string
	style       string
	colorize    bool
	pretty      bool
	initialized bool
}

func (j *JSONOutputHandler) init() {
	if j.initialized {
		return
	}

	j.colorize = false
	j.pretty = false
	j.indent = "\t"
	j.style = "native"
	j.initialized = true
}

// Name implements OutputHandler.Name().
func (j *JSONOutputHandler) Name() string {
	return "json"
}

// SetOption implements OutputHandler.SetOption().
func (j *JSONOutputHandler) SetOption(name string, value string) error {
	j.init()

	switch name {
	case "output.colorize":
		j.colorize = util.StringToValue(value).(bool)
	case "output.pretty":
		j.pretty = util.StringToValue(value).(bool)
	case "output.indent":
		j.indent = value
	case "output.style":
		j.style = value
	}

	return nil
}

// Format implements OutputHandler.Format()
func (j *JSONOutputHandler) Format(writer io.Writer, data interface{}) error {
	var err error
	var jsonBytes []byte

	j.init()

	if j.pretty {
		jsonBytes, err = json.MarshalIndent(data, "", j.indent)
		if err != nil {
			return err
		}
	} else {
		jsonBytes, err = json.Marshal(data)
		if err != nil {
			return err
		}
	}

	if j.colorize {
		err := quick.Highlight(writer, string(jsonBytes), "json", "terminal", j.style)
		if err != nil {
			return err
		}
	} else {
		_, err := writer.Write(jsonBytes)
		if err != nil {
			return err
		}
	}

	return nil
}
